
## CATO-CLI - query.admin:
[Click here](https://api.catonetworks.com/documentation/#query-query.admin) for documentation on this operation.

### Usage for query.admin:

`catocli query admin -h`

`catocli query admin <json>`

`catocli query admin "$(cat < query.admin.json)"`

`catocli query admin '{"adminID":"id"}'`


#### Operation Arguments for query.admin ####

`accountId` [ID] - (required) N/A    
`adminID` [ID] - (required) N/A    
